package it.andynaz.utils;

import static java.lang.System.out;
import java.io.*;
import java.sql.*;
import javax.servlet.http.HttpServletRequest;


/**
 * <p>Metodi utili per la gestione di applicazioni web.</p>
 * 
 * @author andynaz
 * @version 0.1 - 2012/07/24
 */
public abstract class UtilsWEB{
	// nasconde il costruttore
	private UtilsWEB(){}
	
	/**
	 * <p>Prende dalla request il paramentro numerico <tt>nome</tt>.</p>
	 * 
	 * <p>Nel caso in cui non sia possibile (ad esempio perch&eacute; il valore
	 * non esiste o non &egrave; un valore numerico) restituisce il valore
	 * <tt>null</tt>.</p>
	 *
	 * @param req request da cui prendere il parametro
	 * @param nome nome del parametro
	 * 
	 * @return un oggetto <code>Integer</code> con il valore del paramentro
	 *   <tt>nome</tt>, se questo &egrave; presente e numerico, <tt>null</tt>
	 *   altrimenti
	 * 
	 * @throws NullPointerException se req o nome &egrave; <tt>null</tt>
	 * @throws IllegalArgumentException se nome ha lunghezza 0
	 * 
	 * @since 0.1
	 */
	public static Integer getIntegerParameter(HttpServletRequest req, String nome){
		if( req==null ) throw new NullPointerException("la richiesta HTTP non pu\u00F2 essere nulla");
		if( nome==null ) throw new NullPointerException("il nome del paramentro non pu\u00F2 essere nullo");
		if( nome.length()==0 ) throw new IllegalArgumentException("il nome del paramentro non pu\u00F2 essere vuoto");
		
		return Utils.parseInt(req.getParameter(nome));
	}
	
}
